@@ -1,5 +1,5 @@
 from .tracking import AbstractCreateUpdateTime, AbstractCreateUpdateUser, AbstractDeleteTime, AbstractDeleteUser
-from .uuid import AbstractUUID
+from .uuid import AbstractUUID, AbstractUUIDAsPK
 from .slug import AbstractUniqueNameSlug
 from .fk import AbstractForeignKeySelect
 from .other import AbstractStringPK, AbstractOrdering
